InventoryItemModel class

Annotations
  • @Freezed.new()

Constructors

InventoryItemModel({String? id, String? url, String? title, List<ImageInfo>? images, String? description, bool? isCoupon, String? creator, int? numberOfScans, String? code, int? quantityRemaining, int? maximumRedemptions})
const
factory
InventoryItemModel.fromJson(Map<String, dynamic> json)
factory

Properties

code String?
no setterinherited
copyWith → $InventoryItemModelCopyWith<InventoryItemModel>
no setterinherited
creator String?
no setterinherited
description String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
no setterinherited
images List<ImageInfo>?
no setterinherited
isCoupon bool?
no setterinherited
maximumRedemptions int?
no setterinherited
numberOfScans int?
no setterinherited
quantityRemaining int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
no setterinherited
url String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited